==> qiho-center-api-2.5.9-20200810.061007-2-sources.jar: com/qiho/center/api/params/OrderAuditParams.java <==
package com.qiho.center.api.params;

import com.qiho.center.api.enums.order.OrderOperatorTypeEnum;

import java.io.Serializable;

/**
 * Created by liuyao on 2017/6/3. 提交订单审核
 */
public class OrderAuditParams implements Serializable {

    public static final int AUDIT_SUCCESS = 1;
    public static final int AUDIT_FAILED  = 0;

    private String          orderId;
    private Integer         auditResult;
    private String          remark;
    /**
     * 操作人类型 {@link OrderOperatorTypeEnum}
     */
    private Integer         operatorType;

    /**
     * orderId.
     *
     * @return the orderId
     */
    public String getOrderId() {
        return orderId;
    }

    /**
     * orderId.
     *
     * @param orderId the orderId to set
     */
    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    /**
     * auditResult.
     *
     * @return the auditResult
     */
    public Integer getAuditResult() {
        return auditResult;
    }

    /**
     * auditResult.
     *
     * @param auditResult the auditResult to set
     */
    public void setAuditResult(Integer auditResult) {
        this.auditResult = auditResult;
    }

    /**
     * remark.
     *
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * remark.
     *
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }
}

==> qiho-center-api-2.5.82-sources.jar: com/qiho/center/api/params/OrderAuditParams.java <==
package com.qiho.center.api.params;

import com.qiho.center.api.enums.order.OrderOperatorTypeEnum;

import java.io.Serializable;

/**
 * Created by liuyao on 2017/6/3. 提交订单审核
 */
public class OrderAuditParams implements Serializable {

    public static final int AUDIT_SUCCESS = 1;
    public static final int AUDIT_FAILED  = 0;

    private String          orderId;
    private Integer         auditResult;
    private String          remark;
    /**
     * 操作人类型 {@link OrderOperatorTypeEnum}
     */
    private Integer         operatorType;

    /**
     * 取消操作类型 {@link com.qiho.center.api.enums.CancelOperateTypeEnum}
     * */
    private Integer         cancelOperateType;

    private String          cancelOperator;

    /**
     * orderId.
     *
     * @return the orderId
     */
    public String getOrderId() {
        return orderId;
    }

    /**
     * orderId.
     *
     * @param orderId the orderId to set
     */
    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    /**
     * auditResult.
     *
     * @return the auditResult
     */
    public Integer getAuditResult() {
        return auditResult;
    }

    /**
     * auditResult.
     *
     * @param auditResult the auditResult to set
     */
    public void setAuditResult(Integer auditResult) {
        this.auditResult = auditResult;
    }

    /**
     * remark.
     *
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * remark.
     *
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }

    public Integer getCancelOperateType() {
        return cancelOperateType;
    }

    public void setCancelOperateType(Integer cancelOperateType) {
        this.cancelOperateType = cancelOperateType;
    }

    public String getCancelOperator() {
        return cancelOperator;
    }

    public void setCancelOperator(String cancelOperator) {
        this.cancelOperator = cancelOperator;
    }
}
